@@ -111,8 +111,8 @@ def board(
     board_factory:
         An optional board class to use as the constructor.
 
-    Note
-    ----
+    Notes
+    -----
     Many fsspec implementations of filesystems cache the searching of files, which may
     cause you to not see pins saved by other people. Disable this on these file systems
     with `storage_options = {"listings_expiry_time": 0}` on s3, or `{"cache_timeout": 0}`
@@ -256,8 +256,8 @@ def board_github(
     **kwargs:
         Passed to the pins.board function.
 
-    Note
-    ----
+    Notes
+    -----
     This board is read only.
 
 
@@ -289,7 +289,18 @@ def board_github(
     )
 
 
-def board_urls(path: str, pin_paths: dict, cache=DEFAULT, allow_pickle_read=None):
+def board_urls(*args, **kwargs):
+    """DEPRECATED: This board has been renamed to board_url."""
+    from .utils import warn_deprecated
+
+    warn_deprecated(
+        "board_urls has been renamed to board_url. Please use board_url instead."
+    )
+
+    return board_url(*args, **kwargs)
+
+
+def board_url(path: str, pin_paths: dict, cache=DEFAULT, allow_pickle_read=None):
     """Create a board from individual urls.
 
     Parameters
@@ -309,7 +320,7 @@ def board_urls(path: str, pin_paths: dict, cache=DEFAULT, allow_pickle_read=None
     ...     "df_csv": "df_csv/20220214T163720Z-9bfad/",
     ...     "df_arrow": "df_arrow/20220214T163720Z-ad0c1/",
     ... }
-    >>> board = board_urls(github_raw, pin_paths)
+    >>> board = board_url(github_raw, pin_paths)
     >>> board.pin_list()
     ['df_csv', 'df_arrow']
     """
@@ -350,6 +361,31 @@ def board_rsconnect(
         CONNECT_API_KEY environment variable.
     **kwargs:
         Passed to the pins.board function.
+
+    Examples
+    --------
+    Use a server url or set the CONNECT_SERVER environt variable to connect:
+
+    ::
+
+       server_url = "https://connect.rstudioservices.com"
+       board = board_rsconnect(server_url)
+
+    In order to read a public pin, use board_manual with the public pin url.
+
+    ::
+
+       # for a pin at https://connect.rstudioservices.com/content/3004/
+       board = board_url(
+           "https://connect.rstudioservices.com/content",
+           {"my_df": "3004/"}
+       )
+       board.pin_read("my_df")
+
+    See Also
+    --------
+    board_url : board for connecting to individual pins, using a url or path.
+
     """
 
     # TODO: api_key can be passed in to underlying RscApi, equiv to R's manual mode
@@ -374,12 +410,14 @@ def board_s3(path, versioned=True, cache=DEFAULT, allow_pickle_read=None):
     **kwargs:
         Passed to the pins.board function.
 
-    Note
-    ----
+    Notes
+    -----
     The s3 board uses the fsspec library (s3fs) to handle interacting with s3.
     In order to authenticate, set the AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY,
     and (optionally) AWS_REGION environment variables.
 
+    See https://github.com/fsspec/s3fs
+
     """
     # TODO: user should be able to specify storage options here?
 
@@ -397,8 +435,8 @@ def board_gcs(path, versioned=True, cache=DEFAULT, allow_pickle_read=None):
     **kwargs:
         Passed to the pins.board function.
 
-    Note
-    ----
+    Notes
+    -----
     The gcs board uses the fsspec library (gcsfs) to handle interacting with
     google cloud storage. Currently, its default mode of authentication
     is supported.
@@ -410,3 +448,28 @@ def board_gcs(path, versioned=True, cache=DEFAULT, allow_pickle_read=None):
     # fixes it under the hood
     opts = {"cache_timeout": 0}
     return board("gcs", path, versioned, cache, allow_pickle_read, storage_options=opts)
+
+
+def board_azure(path, versioned=True, cache=DEFAULT, allow_pickle_read=None):
+    """Create a board to read and write pins from an Google Cloud Storage bucket folder.
+
+    Parameters
+    ----------
+    path:
+        Path of form <bucket_name>/<optional>/<subdirectory>.
+    **kwargs:
+        Passed to the pins.board function.
+
+    Notes
+    -----
+    The azure board uses the fsspec library (adlfs) to handle interacting with
+    Azure Datalake Filesystem (abfs). Currently, its default mode of authentication
+    is supported.
+
+    See https://github.com/fsspec/adlfs
+    """
+
+    opts = {"use_listings_cache": False}
+    return board(
+        "abfs", path, versioned, cache, allow_pickle_read, storage_options=opts
+    )
